@@ -263,7 +263,8 @@ class BaseDeployment(ABC):
                 pipeline_model=artifact_name,
                 deployment_name=kwargs['deployment_name'],
                 serving_name=kwargs.get('serving_name'),
-                meta_props=model_props
+                meta_props=model_props,
+                hardware_spec=kwargs.get('hardware_spec')
             )
 
             remove_file(filename=artifact_name)
