@@ -331,10 +331,13 @@ class WMLEngine(BaseEngine):
                     'pipelines'][0]['nodes'][0]['parameters']['optimization']\
                     .update(get_values_for_imputation_strategy(
                     self._auto_pipelines_parameters.get('numerical_imputation_strategy'),
-                    self._auto_pipelines_parameters.get('prediction_type')))
+                    self._auto_pipelines_parameters.get('prediction_type'),
+                    self._auto_pipelines_parameters.get('numerical_imputation_value')))
 
                 if self._auto_pipelines_parameters.get('numerical_imputation_value') is not None:
-                    if self._auto_pipelines_parameters.get('numerical_imputation_strategy') == ImputationStrategy.VALUE:
+                    if self._auto_pipelines_parameters.get('numerical_imputation_strategy') == ImputationStrategy.VALUE\
+                            or (type(self._auto_pipelines_parameters.get('numerical_imputation_strategy')) is list
+                                and ImputationStrategy.VALUE in self._auto_pipelines_parameters.get('numerical_imputation_strategy')):
                         self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                             'pipelines'][0]['nodes'][0]['parameters']['optimization']['imputer_fill_value'] = \
                             self._auto_pipelines_parameters.get('numerical_imputation_value')
