@@ -163,6 +163,10 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                  fairness_info: dict = None,
                  retrain_on_holdout: bool = True,
                  **kwargs):
+        
+        if data_join_graph is not None:
+            data_join_graph.fairness_info = fairness_info
+
         self.params = {
             'name': name,
             'desc': desc if desc else '',
