@@ -256,9 +256,9 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
                 'timestamp_column_name': ts_parameters.get('timestamp_column'),
                 'holdout_size': ts_parameters['holdout_param'],
                 'max_num_daub_ensembles': ts_parameters['max_num_daub_ensembles'],
-                'backtest_gap_length': ts_parameters.get('backtest_gap_length'),
-                'backtest_num': ts_parameters.get('backtest_num'),
-                'forecast_window': ts_parameters.get('forecast_window'),
+                'backtest_gap_length': ts_parameters.get('gap_len'),
+                'backtest_num': ts_parameters.get('num_backtest'),
+                'forecast_window': ts_parameters.get('prediction_horizon'),
                 'include_only_estimators': ts_parameters.get('include_only_estimators'),
                 'lookback_window': ts_parameters.get('lookback_window'),
                 't_shirt_size': ts_wml_data['hardware_spec']['id'],
