@@ -13,7 +13,7 @@
 #  limitations under the License.
 
 from __future__ import print_function
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 import json
 from ibm_watson_machine_learning.utils import DEPLOYMENT_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, print_text_header_h1, \
     print_text_header_h2, STR_TYPE, STR_TYPE_NAME, docstring_parameter, str_type_conv, \
@@ -36,7 +36,6 @@ class Factsheets(WMLResource):
         if not client.ICP and not client.CLOUD_PLATFORM_SPACES and not client.ICP_PLATFORM_SPACES:
             Factsheets._validate_type(client.service_instance.details, u'instance_details', dict, True)
             Factsheets._validate_type_of_details(client.service_instance.details, INSTANCE_DETAILS_TYPE)
-        self.session = requests.Session()
         self._ICP = client.ICP
         self.ConfigurationMetaNames = FactsheetsMetaNames()
 
@@ -139,14 +138,12 @@ class Factsheets(WMLResource):
                     url,
                     json=metaProps,
                     params=params,  # version is mandatory
-                    headers=self._client._get_headers(),
-                    verify=False)
+                    headers=self._client._get_headers())
             else:
                 response = requests.post(
                     url,
                     json=metaProps,
-                    headers=self._client._get_headers(),
-                    verify=False)
+                    headers=self._client._get_headers())
 
         if response.status_code == 200:
             print_text_header_h2(f"Successfully finished linking WML Model '{model_id}' to Model Entry.")
@@ -206,13 +203,11 @@ class Factsheets(WMLResource):
                 response = requests.get(
                     url,
                     params=self._client._params(),  # version is mandatory
-                    headers=self._client._get_headers(),
-                    verify=False)
+                    headers=self._client._get_headers())
             else:
                 response = requests.get(
                     url,
-                    headers=self._client._get_headers(),
-                    verify=False)
+                    headers=self._client._get_headers())
 
         if response.status_code == 200:
             return response.json()
@@ -276,18 +271,10 @@ class Factsheets(WMLResource):
                     params=params,
                     headers=self._client._get_headers())
         else:
-            if self._client.ICP_PLATFORM_SPACES:
-                response = requests.delete(
-                    url,
-                    params=params,  # version is mandatory
-                    headers=self._client._get_headers(),
-                    verify=False)
-            else:
-                response = requests.delete(
-                    url,
-                    params=params,
-                    headers=self._client._get_headers(),
-                    verify=False)
+            response = requests.delete(
+                url,
+                params=params,  # version is mandatory
+                headers=self._client._get_headers())
 
         if response.status_code == 204:
             print_text_header_h2(f"Successfully finished unregistering WKC Model '{asset_id}' Entry.")
