@@ -42,7 +42,7 @@ from warnings import warn
 from ibm_boto3 import resource
 from ibm_botocore.client import ClientError
 from pandas import DataFrame
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 
 from ibm_watson_machine_learning.utils.autoai.enums import PredictionType, DataConnectionTypes
 from ibm_watson_machine_learning.utils.autoai.errors import (
@@ -1021,7 +1021,7 @@ class FSLocation(BaseLocation):
             url = workspace.wml_client.service_instance._href_definitions.get_wsd_model_attachment_href() \
                   + f"/{self.path.split('/assets/')[-1]}"
             path_info_response = requests.head(url, headers=workspace.wml_client._get_headers(),
-                                               params=workspace.wml_client._params(), verify=False)
+                                               params=workspace.wml_client._params())
             if path_info_response.status_code != 200:
                 raise ApiRequestFailure(u"Failure during getting path details", path_info_response)
             path_info = path_info_response.headers
@@ -1083,7 +1083,7 @@ class AssetLocation(BaseLocation):
 
         if client.ICP:
             attachment = requests.get(attachment_url, headers=client._get_headers(),
-                                      params=client._params(), verify=False)
+                                      params=client._params())
 
         else:
             attachment = requests.get(attachment_url, headers=client._get_headers(),
@@ -1129,11 +1129,10 @@ class AssetLocation(BaseLocation):
         if self._wsd:
             return self._wsd_get_file_size()
         else:
-            verify_request = False if workspace.wml_client.ICP else True
             asset_info_response = requests.get(
                 workspace.wml_client.service_instance._href_definitions.get_data_asset_href(self.id),
                 params=workspace.wml_client._params(),
-                headers=workspace.wml_client._get_headers(), verify=verify_request)
+                headers=workspace.wml_client._get_headers())
             if asset_info_response.status_code != 200:
                 raise ApiRequestFailure(u"Failure during getting asset details", asset_info_response)
             return asset_info_response.json()['metadata'].get('size')
@@ -1324,7 +1323,7 @@ class NFSLocation(BaseLocation):
 
         href = workspace.wml_client.connections._href_definitions.get_connection_by_id_href(self.id) + '/assets'
         asset_info_response = requests.get(href,
-                                           params=params, headers=workspace.wml_client._get_headers(None), verify=False)
+                                           params=params, headers=workspace.wml_client._get_headers(None))
         if asset_info_response.status_code != 200:
             raise Exception(u"Failure during getting asset details", asset_info_response.json())
         return asset_info_response.json()['details']['file_size']
