@@ -13,7 +13,7 @@
 #  limitations under the License.
 
 from __future__ import print_function
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 from ibm_watson_machine_learning.utils import STR_TYPE, STR_TYPE_NAME, docstring_parameter
 from ibm_watson_machine_learning.metanames import Migrationv4GACloudMetaNames
 import os
@@ -194,8 +194,7 @@ class Migrationv4GACloud(WMLResource):
 
         cancel_response = requests.delete(href,
                                           params=params,
-                                          headers=self._client._get_headers(),
-                                          verify=False)
+                                          headers=self._client._get_headers())
 
         details = self._handle_response(expected_status_code=204,
                                         operationName=u'cancel migration',
@@ -249,8 +248,7 @@ class Migrationv4GACloud(WMLResource):
 
         delete_response = requests.delete(href,
                                           params=params,
-                                          headers=self._client._get_headers(),
-                                          verify=False)
+                                          headers=self._client._get_headers())
 
         details = self._handle_response(expected_status_code=204,
                                         operationName=u'delete migration',
