@@ -13,7 +13,7 @@
 #  limitations under the License.
 
 from __future__ import print_function
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 from ibm_watson_machine_learning.utils import SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos
 from ibm_watson_machine_learning.metanames import ModelDefinitionMetaNames, MetaNamesBase,  MetaNames
 from ibm_watson_machine_learning.wml_resource import WMLResource
@@ -224,8 +224,7 @@ class ModelDefinition(WMLResource):
                     self._client.service_instance._href_definitions.get_model_definition_assets_href(),
                     params=paramvalue,
                     headers=self._client._get_headers(),
-                    json=document,
-                    verify=False)
+                    json=document)
 
             model_definition_details = self._handle_response(201, u'creating new model_definition', creation_response)
 
@@ -244,15 +243,13 @@ class ModelDefinition(WMLResource):
                         model_definition_attachment_url,
                         params=paramvalue,
                         headers=self._client._get_headers(),
-                        json=model_definition_attachment_def,
-                        verify=False)
+                        json=model_definition_attachment_def)
                 else:
                     attachment_response = requests.post(
                          model_definition_attachment_url,
                          params=paramvalue,
                          headers=self._client._get_headers(),
-                         json=model_definition_attachment_def,
-                         verify=False)
+                         json=model_definition_attachment_def)
                 attachment_details = self._handle_response(201, u'creating new attachment', attachment_response)
                 if attachment_response.status_code == 201:
                     attachment_id = attachment_details['attachment_id']
@@ -272,21 +269,18 @@ class ModelDefinition(WMLResource):
                     else:
 
                         put_response = requests.put(model_definition_attachment_put_url,
-                                                    files=files,
-                                                    verify=False)
+                                                    files=files)
                     if put_response.status_code == 201 or put_response.status_code == 200:
                         complete_url = self._client.service_instance._href_definitions.get_attachment_href(model_definition_id, attachment_id) \
                                        + "/complete"
                         if not self._ICP:
                             complete_response = requests.post( self._client.service_instance._href_definitions.get_attachment_complete_href(model_definition_id, attachment_id),
                                                               params=paramvalue,
-                                                              headers=self._client._get_headers(),
-                                                              verify=False)
+                                                              headers=self._client._get_headers())
                         else:
                             complete_response = requests.post(complete_url,
                                                               params=paramvalue,
-                                                              headers=self._client._get_headers(),
-                                                              verify=False)
+                                                              headers=self._client._get_headers())
 
                         if complete_response.status_code == 200:
                             response = self._get_required_element_from_response(model_definition_details)
@@ -366,8 +360,7 @@ class ModelDefinition(WMLResource):
             response_get = requests.get(
                 url,
                 params=paramvalue,
-                headers=self._client._get_headers(),
-                verify=False
+                headers=self._client._get_headers()
             )
         if response_get.status_code == 200:
             get_model_definition_details = self._handle_response(200, op_name, response_get)
@@ -450,7 +443,7 @@ class ModelDefinition(WMLResource):
                                     headers=self._client._get_headers())
             else:
                 response = requests.get(artifact_content_url, params=self._client._params(),
-                                    headers=self._client._get_headers(), verify=False)
+                                    headers=self._client._get_headers())
             attachment_signed_url = response.json()["url"]
         if response.status_code == 200:
             if not self._ICP and not self._client.WSD:
@@ -462,11 +455,10 @@ class ModelDefinition(WMLResource):
                 if self._client.WSD:
                     att_response = requests.get(attachment_signed_url, params= self._client._params(),
                                                 headers=self._client._get_headers(),
-                                                stream=True, verify=False)
+                                                stream=True)
                 else:
-                    att_response = requests.get(self._wml_credentials["url"]+attachment_signed_url,
+                    att_response = requests.get(self._wml_credentials["url"]+attachment_signed_url)
 
-                                                verify=False)
             if att_response.status_code != 200:
                 raise WMLClientError(u'Failure during {}.'.format("downloading model_definition asset"),
                                      att_response)
@@ -514,7 +506,7 @@ class ModelDefinition(WMLResource):
         if not self._ICP:
             response_delete = requests.delete(model_definition_endpoint, params=paramvalue, headers=self._client._get_headers())
         else:
-            response_delete = requests.delete(model_definition_endpoint, params=paramvalue, headers=self._client._get_headers(), verify=False)
+            response_delete = requests.delete(model_definition_endpoint, params=paramvalue, headers=self._client._get_headers())
 
         return self._handle_response(204, u'Model definition deletion', response_delete, False)
 
@@ -548,7 +540,7 @@ class ModelDefinition(WMLResource):
         if not self._ICP:
             response_delete = requests.delete(model_definition_endpoint, params=paramvalue, headers=self._client._get_headers())
         else:
-            response_delete = requests.delete(model_definition_endpoint, params=paramvalue, headers=self._client._get_headers(), verify=False)
+            response_delete = requests.delete(model_definition_endpoint, params=paramvalue, headers=self._client._get_headers())
 
     def _get_required_element_from_response(self, response_data):
 
@@ -623,19 +615,11 @@ class ModelDefinition(WMLResource):
         if rev_id is not None:
             paramvalue.update({'revision_id': rev_id})
 
-        if not self._ICP:
-            response_get = requests.get(
-                url,
-                params=paramvalue,
-                headers=self._client._get_headers()
-            )
-        else:
-            response_get = requests.get(
-                url,
-                params=paramvalue,
-                headers=self._client._get_headers(),
-                verify=False
-            )
+        response_get = requests.get(
+            url,
+            params=paramvalue,
+            headers=self._client._get_headers()
+        )
         details = self._handle_response(200, op_name, response_get)
         attachment_id = details["attachments"][0]["id"]
         return attachment_id
@@ -678,7 +662,7 @@ class ModelDefinition(WMLResource):
         if not self._ICP:
             response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(),json=data)
         else:
-            response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(),json=data, verify=False)
+            response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(),json=data)
         self._handle_response(200, u'model_definition assets', response)
         asset_details = self._handle_response(200, u'model_definition assets', response)["results"]
         model_def_values = [
@@ -830,19 +814,11 @@ class ModelDefinition(WMLResource):
         # STEP 4. Get the updated script record and return
 
         # STEP 1
-        if not self._ICP:
-            response = requests.get(
-                url,
-                params=self._client._params(),
-                headers=self._client._get_headers()
-            )
-        else:
-            response = requests.get(
-                url,
-                params=self._client._params(),
-                headers=self._client._get_headers(),
-                verify=False
-            )
+        response = requests.get(
+            url,
+            params=self._client._params(),
+            headers=self._client._get_headers()
+        )
 
         if response.status_code != 200:
             if response.status_code == 404:
@@ -888,17 +864,10 @@ class ModelDefinition(WMLResource):
             if meta_patch_payload:
                 meta_patch_url = self._client.service_instance._href_definitions.get_asset_href(model_definition_id)
 
-                if not self._ICP:
-                    response_patch = requests.patch(meta_patch_url,
-                                                    json=meta_patch_payload,
-                                                    params=self._client._params(),
-                                                    headers=self._client._get_headers())
-                else:
-                    response_patch = requests.patch(meta_patch_url,
-                                                    json=meta_patch_payload,
-                                                    params=self._client._params(),
-                                                    headers=self._client._get_headers(),
-                                                    verify=False)
+                response_patch = requests.patch(meta_patch_url,
+                                                json=meta_patch_payload,
+                                                params=self._client._params(),
+                                                headers=self._client._get_headers())
 
                 updated_details = self._handle_response(200, u'script patch', response_patch)
 
@@ -915,7 +884,7 @@ class ModelDefinition(WMLResource):
                     response_patch = requests.patch(entity_patch_url,
                                                     json=entity_patch_payload,
                                                     params=self._client._params(),
-                                                    headers=self._client._get_headers(), verify=False)
+                                                    headers=self._client._get_headers())
 
                 updated_details = self._handle_response(200, u'script patch', response_patch)
 
@@ -937,19 +906,11 @@ class ModelDefinition(WMLResource):
         # Have to fetch again to reflect updated asset and attachment ids
         url = self._client.service_instance._href_definitions.get_asset_href(model_definition_id)
 
-        if not self._ICP:
-            response = requests.get(
-                url,
-                params=self._client._params(),
-                headers=self._client._get_headers()
-            )
-        else:
-            response = requests.get(
-                url,
-                params=self._client._params(),
-                headers=self._client._get_headers(),
-                verify=False
-            )
+        response = requests.get(
+            url,
+            params=self._client._params(),
+            headers=self._client._get_headers()
+        )
 
         if response.status_code != 200:
             if response.status_code == 404:
@@ -1090,19 +1051,11 @@ class ModelDefinition(WMLResource):
 
         paramvalue.update({'revision_id': rev_uid})
 
-        if not self._ICP:
-            response_get = requests.get(
-                url,
-                params=paramvalue,
-                headers=self._client._get_headers()
-            )
-        else:
-            response_get = requests.get(
-                url,
-                params=paramvalue,
-                headers=self._client._get_headers(),
-                verify=False
-            )
+        response_get = requests.get(
+            url,
+            params=paramvalue,
+            headers=self._client._get_headers()
+        )
         if response_get.status_code == 200:
             # get_model_definition_details = self._handle_response(200, op_name, response_get)
             # return self._get_required_element_from_response(get_model_definition_details)
@@ -1170,7 +1123,7 @@ class ModelDefinition(WMLResource):
         if not self._ICP:
             response = requests.get(href, params, headers=self._client._get_headers())
         else:
-            response = requests.get(href, params=params, headers=self._client._get_headers(), verify=False)
+            response = requests.get(href, params=params, headers=self._client._get_headers())
         self._handle_response(200, u'model_definition revision assets', response)
         asset_details = self._handle_response(200, u'model_definition revision assets', response)["results"]
         model_def_values = [
