@@ -17,7 +17,8 @@
 import os
 import sys
 import importlib.util
-
+from pathlib import Path
+import platform
 import ibm_watson_machine_learning._wrappers.requests as requests
 import json
 import logging
@@ -41,8 +42,11 @@ def process_heartbeat(client, **kwargs):
 
         if service_version.startswith("4.0"):
             version_details = service_version.split('-')
-            if version_details[1] >= "202110":
-                return "general"
+            #use cpd403 for cpd4.0.x version for now
+            if version_details[1] >= "202112":
+                return "cpd406"
+            elif version_details[1] >= "202110":
+                return "cpd403"
             elif version_details[1] >= "202108":
                 return "cpd402"
             else:
@@ -50,22 +54,50 @@ def process_heartbeat(client, **kwargs):
         if service_version.startswith("35"):
             return "cpd35"
 
-        return "general"
+        return "cloud"
 
     except Exception as ex:
         logger.info("unable to process heartbeat")
         logger.exception(ex)
-        return "general"
+        return "cloud"
 
 
-def import_source(module_file_path):
-    module_name = 'ibmfl'
+def import_diff(module_file_path):
 
-    module_spec = importlib.util.spec_from_file_location(
-        module_name, module_file_path)
-    module = importlib.util.module_from_spec(module_spec)
-    sys.modules[module_name] = module
-    module_spec.loader.exec_module(module)
+    if "sklearn023" in module_file_path:
+        return
+    pathlist = Path(module_file_path).rglob('*.py')
+    for path in pathlist:
+        # because path is object not string
+        path_in_str = str(path)
+        if not path_in_str.endswith("__init__.py"):
+            module_name = ("ibmfl" + path_in_str.split("ibmfl")[2].replace("/", "."))[:-3]
+            module_spec = importlib.util.spec_from_file_location(
+                module_name, path_in_str)
+            module = importlib.util.module_from_spec(module_spec)
+            sys.modules[module_name] = module
+            module_spec.loader.exec_module(module)
+
+
+def choose_sklearn_version(software_spec):
+    if software_spec == "runtime-22.1-py3.9" or software_spec == "12b83a17-24d8-5082-900f-0ab31fbfd3cb":
+        return "sklearn102"
+    else:
+        return "sklearn023"
+
+
+def check_python_version(platform_env):
+    py_version = platform.python_version()
+    if platform_env != "cloud":
+        if not py_version.startswith("3.7.") and not py_version.startswith("3.8."):
+            raise Exception("Python version {} is not supported for Federated Learning. "
+                            "Parties must use a supported Python version to train the model. "
+                            "For details, please refer to the documentation".format(py_version))
+    else:
+        if not py_version.startswith("3.7.") and not py_version.startswith("3.8.") and not py_version.startswith("3.9"):
+            raise Exception("Python version {} is not supported for Federated Learning. "
+                            "Parties must use a supported Python version to train the model. "
+                            "For details, please refer to the documentation".format(py_version))
 
 
 fl_path = os.path.abspath('.')
@@ -79,10 +111,14 @@ class Party(WMLResource):
     """
 
     SUPPORTED_PLATFORMS_MAP = {
-        'general': "/cloud/ibmfl/__init__.py",
-        'cpd35': "/cpd35/ibmfl/__init__.py",
+        'cloud': "/cloud/ibmfl",
+        'cpd35': "1.0.181",
         'cpd401': "1.0.122",
-        'cpd402': "1.0.165"
+        'cpd402': "1.0.165",
+        'cpd403': "/cpd403/ibmfl",
+        'cpd406': "/cpd406/ibmfl",
+        'sklearn023': "/sklearn023/ibmfl",
+        'sklearn102': "/sklearn102/ibmfl"
     }
 
     def __init__(self, client=None, **kwargs):
@@ -91,16 +127,25 @@ class Party(WMLResource):
         libs_location_list = libs_module.__path__
 
         # base location string, default to cloud location
-        ibmfl_module_location = libs_location_list[0] + '/ibmfl'
+        ibmfl_base_module_location = libs_location_list[0] + '/ibmfl'
 
         # get arg for platform
         calculated_platform_env = process_heartbeat(client=client, **kwargs)
         platform_env = kwargs.get('env', calculated_platform_env)
+
+        #check python version
+        check_python_version(platform_env)
+
         # process location
-        ibmfl_module_location = ibmfl_module_location + self.SUPPORTED_PLATFORMS_MAP.get(platform_env)
-        if not ibmfl_module_location.endswith(".py"):
-        	print("Please use ibm-watson-machine-learning " + self.SUPPORTED_PLATFORMS_MAP.get(platform_env) )
-        	exit()
+        ibmfl_module_location = ibmfl_base_module_location + self.SUPPORTED_PLATFORMS_MAP.get(platform_env)
+        if not ibmfl_module_location.endswith("ibmfl"):
+            raise Exception("Please use ibm-watson-machine-learning " + self.SUPPORTED_PLATFORMS_MAP.get(platform_env) )
+
+        #check if using old connector script which is removed
+        if not client:
+            raise Exception("This version of the party connector script is outdated. "
+                            "Please download the party connector script from your current Federated Learning experiment. "
+                            "For more details, please refer to the documentation.")
 
         self.module_location = ibmfl_module_location
         self.args = kwargs
@@ -115,18 +160,20 @@ class Party(WMLResource):
             del sys.modules['ibmfl.party']
         if 'ibmfl.party.party' in sys.modules:
             del sys.modules['ibmfl.party.party']
-        if client:
-            WMLResource.__init__(self, __name__, client)
-            self._client = client
-            self.auth_token = "Bearer " + self._client.wml_token
-            self.project_id = self._client.project_id
-            self.log_level = kwargs.get("log_level", "ERROR")
-        else:
-            self.log_level = kwargs.get("log_level", "INFO")
-            import_source(self.module_location)
-            from ibmfl.party.party import Party
-            self.Party = Party(**self.args)
-            self.connection = self.Party.connection
+
+        #install the general lib (which is the cloud version)
+        module_name = 'ibmfl'
+        module_spec = importlib.util.spec_from_file_location(
+            module_name, ibmfl_base_module_location + '/sklearn023/ibmfl/__init__.py')
+        module = importlib.util.module_from_spec(module_spec)
+        sys.modules[module_name] = module
+        module_spec.loader.exec_module(module)
+
+        WMLResource.__init__(self, __name__, client)
+        self._client = client
+        self.auth_token = "Bearer " + self._client.wml_token
+        self.project_id = self._client.project_id
+        self.log_level = kwargs.get("log_level", "ERROR")
 
     def start(self):
         self.Party.start()
@@ -153,8 +200,7 @@ class Party(WMLResource):
          >>> party.run( aggregator_id , asynchronous = True, verify = True )
 
         """
-        import_source(self.module_location)
-        from ibmfl.party.party import Party
+        #import the changed files in the desired lib version
 
         config_dict = self.args.get('config_dict')
         metrics_config = {
@@ -177,6 +223,7 @@ class Party(WMLResource):
         try:
             training_status = self._client.training.get_status(aggregator_id)
             state = training_status['state']
+            ready = False
             if state == "pending":
                 while state == "pending":
                     logger.info("Waiting for aggregator accepting parties state..")
@@ -185,16 +232,30 @@ class Party(WMLResource):
                     time.sleep(10)
                 if state != "accepting_parties":
                     raise FLException("The current state of training is %s, so the party is not able to start a job." % state)
-                self.Party = Party(**self.args, token=self.auth_token, self_signed_cert=not verify, log_level=self.log_level)
-                self.connection = self.Party.connection
-                self.start()
+                ready = True
             elif state == "running" or state == "accepting_parties":
+                ready = True
+            else:
+                raise FLException("The current state of training is %s, so the party is not able to start a job." % state)
+
+            if ready:
+                if "cpd406" in self.module_location:
+                    details = self._client.training.get_details(aggregator_id)
+                    fl_entity = details["entity"]["federated_learning"]
+                    if "software_spec" in fl_entity:
+                        software_spec = fl_entity["software_spec"]["name"] if "name" in fl_entity["software_spec"] else fl_entity["software_spec"]["id"]
+                    else:
+                        software_spec = "default_py3.8"
+                    platform_env = choose_sklearn_version(software_spec)
+                    print("Loading {} environment..".format(platform_env))
+                    self.module_location = '/'.join(self.module_location.split('/')[0:-2]) + self.SUPPORTED_PLATFORMS_MAP.get(platform_env)
+                import_diff(self.module_location)
+                from ibmfl.party.party import Party
                 self.Party = Party(**self.args, token=self.auth_token, self_signed_cert=not verify, log_level=self.log_level)
                 self.connection = self.Party.connection
                 self.start()
             else:
                 raise FLException("The current state of training is %s, so the party is not able to start a job." % state)
-
             #wait for the job to finish if synchrounous
             if not asynchronous:
                 while "completed" != state and "failed" != state and "canceled" != state and self.is_running():
