@@ -215,6 +215,8 @@ class DataJoinGraph(Digraph, BaseOBMJson):
         self.edges_to_ports: Dict[str, str] = {}
         self.node_edges: Dict[str, Set[str]] = {}
 
+        self.fairness_info = None
+
     @property
     def problem_type(self) -> 'PredictionType':
         return self.__problem_type
@@ -386,6 +388,10 @@ class DataJoinGraph(Digraph, BaseOBMJson):
                 }
             }
         }
+
+        if self.fairness_info is not None:
+            _dict['parameters']['fairness_info'] = self.fairness_info
+
         return _dict
 
     @classmethod
@@ -406,6 +412,8 @@ class DataJoinGraph(Digraph, BaseOBMJson):
             from_column=edge['from_column'],
             to_column=edge['to_column']) for edge in _dict['parameters']['obm']['Entity_Graph']['edges']]
 
+        data_join_graph.fairness_info = _dict['parameters'].get('fairness_info')
+
         return data_join_graph
 
     def pretty_print(self, show_imports: bool = True, ipython_display: bool = False) -> Union[str, None]:
