@@ -13,7 +13,7 @@
 #  limitations under the License.
 
 from __future__ import print_function
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 from ibm_watson_machine_learning.utils import SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE,DATA_ASSETS_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos
 from ibm_watson_machine_learning.metanames import ShinyMetaNames
 from ibm_watson_machine_learning.wml_resource import WMLResource
@@ -59,13 +59,9 @@ class Shiny(WMLResource):
         """
         Shiny._validate_type(shiny_uid, u'asset_uid', STR_TYPE, True)
 
+        response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(shiny_uid), params=self._client._params(),
+                                headers=self._client._get_headers())
 
-        if not self._ICP:
-            response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(shiny_uid), params=self._client._params(),
-                                    headers=self._client._get_headers())
-        else:
-            response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(shiny_uid), params=self._client._params(),
-                                      headers=self._client._get_headers(), verify=False)
         if response.status_code == 200:
             response = self._get_required_element_from_response(self._handle_response(200, u'get asset details', response))
 
@@ -222,8 +218,7 @@ class Shiny(WMLResource):
                         self._client.service_instance._href_definitions.get_data_assets_href(),
                         headers=self._client._get_headers(),
                         params=self._client._params(),
-                        json=asset_meta,
-                        verify=False
+                        json=asset_meta
                     )
                 else:
                     # Until global asset for shiny is created
@@ -231,16 +226,14 @@ class Shiny(WMLResource):
                         self._client.service_instance._href_definitions.get_wsd_asset_type_href() + '?',
                         headers=self._client._get_headers(),
                         json=base_shiny_asset,
-                        params=self._client._params(),
-                        verify=False
+                        params=self._client._params()
                     )
                     if asset_type_response.status_code == 201 or asset_type_response.status_code == 409:
                         creation_response = requests.post(
                             self._client.service_instance._href_definitions.get_data_assets_href(),
                             headers=self._client._get_headers(),
                             json=asset_meta,
-                            params=self._client._params(),
-                            verify=False
+                            params=self._client._params()
                         )
 
             asset_details = self._handle_response(201, u'creating new asset', creation_response)
@@ -252,21 +245,12 @@ class Shiny(WMLResource):
                         "name": "attachment_"+asset_id
                     }
 
-                if not self._ICP:
-                    attachment_response = requests.post(
-                        self._client.service_instance._href_definitions.get_attachments_href(asset_id),
-                        headers=self._client._get_headers(),
-                        params=self._client._params(),
-                        json=attachment_meta
-                    )
-                else:
-                    attachment_response = requests.post(
-                        self._client.service_instance._href_definitions.get_attachments_href(asset_id),
-                        headers=self._client._get_headers(),
-                        json=attachment_meta,
-                        params=self._client._params(),
-                        verify=False
-                    )
+                attachment_response = requests.post(
+                    self._client.service_instance._href_definitions.get_attachments_href(asset_id),
+                    headers=self._client._get_headers(),
+                    params=self._client._params(),
+                    json=attachment_meta
+                )
                 attachment_details = self._handle_response(201, u'creating new attachment', attachment_response)
                 if attachment_response.status_code == 201:
                     attachment_id = attachment_details["attachment_id"]
@@ -283,8 +267,7 @@ class Shiny(WMLResource):
                     else:
                         put_response = requests.put(
                             self._wml_credentials['url'] + attachment_url,
-                            files=f,
-                            verify=False
+                            files=f
                         )
                     if put_response.status_code == 201 or put_response.status_code == 200:
                         # Step4: Complete attachment
@@ -300,8 +283,7 @@ class Shiny(WMLResource):
                             complete_response = requests.post(
                                 self._client.service_instance._href_definitions.get_attachment_href(asset_id,attachment_id)+"/complete",
                                 headers=self._client._get_headers(),
-                                params=self._client._params(),
-                                verify=False
+                                params=self._client._params()
                             )
                         if complete_response.status_code == 200:
                             print("SUCCESS")
@@ -349,10 +331,7 @@ class Shiny(WMLResource):
         if limit is not None:
             data.update({"limit": limit})
 
-        if not self._ICP:
-            response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(),json=data)
-        else:
-            response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(),json=data, verify=False)
+        response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(),json=data)
         self._handle_response(200, u'list assets', response)
         asset_details = self._handle_response(200, u'list assets', response)["results"]
         space_values = [
@@ -399,14 +378,9 @@ class Shiny(WMLResource):
             params.update({'revision_id': rev_uid})
 
         import urllib
-        if not self._ICP:
-            asset_response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid),
-                                          params=params,
-                                          headers=self._client._get_headers())
-        else:
-            asset_response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid),
-                                          params=params,
-                                          headers=self._client._get_headers(), verify=False)
+        asset_response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid),
+                                      params=params,
+                                      headers=self._client._get_headers())
         asset_details = self._handle_response(200, u'get assets', asset_response)
 
         if self._WSD:
@@ -415,7 +389,7 @@ class Shiny(WMLResource):
                                    urllib.parse.quote('shiny_asset/' + attachment_url, safe='')
 
             r = requests.get(artifact_content_url, params=self._client._params(), headers=self._client._get_headers(),
-                             stream=True, verify=False)
+                             stream=True)
             if r.status_code != 200:
                 raise ApiRequestFailure(u'Failure during {}.'.format("downloading data asset"), r)
 
@@ -429,26 +403,18 @@ class Shiny(WMLResource):
                 raise WMLClientError(u'Saving data asset with artifact_url: \'{}\'  to local file failed.'.format(filename), e)
         else:
             attachment_id = asset_details["attachments"][0]["id"]
-            if not self._ICP:
-                response = requests.get(self._client.service_instance._href_definitions.get_attachment_href(asset_uid,attachment_id), params=params,
-                                        headers=self._client._get_headers())
-            else:
-                response = requests.get(self._client.service_instance._href_definitions.get_attachment_href(asset_uid,attachment_id), params=params,
-                                          headers=self._client._get_headers(), verify=False)
+            response = requests.get(self._client.service_instance._href_definitions.get_attachment_href(asset_uid,attachment_id), params=params,
+                                    headers=self._client._get_headers())
             if response.status_code == 200:
                 attachment_signed_url = response.json()["url"]
                 if 'connection_id' in asset_details["attachments"][0]:
-                    if not self._ICP:
-                        att_response = requests.get(attachment_signed_url)
-                    else:
-                        att_response = requests.get(attachment_signed_url,
-                                                    verify=False)
+                    att_response = requests.get(attachment_signed_url)
                 else:
                     if not self._ICP:
                         att_response = requests.get(attachment_signed_url)
                     else:
-                        att_response = requests.get(self._wml_credentials["url"]+attachment_signed_url,
-                                                verify=False)
+                        att_response = requests.get(self._wml_credentials["url"]+attachment_signed_url)
+
                 if att_response.status_code != 200:
                     raise ApiRequestFailure(u'Failure during {}.'.format("downloading asset"), att_response)
 
@@ -594,19 +560,11 @@ class Shiny(WMLResource):
         # STEP 4. Get the updated script record and return
 
         # STEP 1
-        if not self._ICP:
-            response = requests.get(
-                url,
-                params=self._client._params(),
-                headers=self._client._get_headers()
-            )
-        else:
-            response = requests.get(
-                url,
-                params=self._client._params(),
-                headers=self._client._get_headers(),
-                verify=False
-            )
+        response = requests.get(
+            url,
+            params=self._client._params(),
+            headers=self._client._get_headers()
+        )
 
         if response.status_code != 200:
             if response.status_code == 404:
@@ -641,16 +599,10 @@ class Shiny(WMLResource):
             if meta_patch_payload:
                 meta_patch_url = self._client.service_instance._href_definitions.get_asset_href(shiny_uid)
 
-                if not self._ICP:
-                    response_patch = requests.patch(meta_patch_url,
-                                                    json=meta_patch_payload,
-                                                    params=self._client._params(),
-                                                    headers=self._client._get_headers())
-                else:
-                    response_patch = requests.patch(meta_patch_url,
-                                                    json=meta_patch_payload,
-                                                    params=self._client._params(),
-                                                    headers=self._client._get_headers(), verify=False)
+                response_patch = requests.patch(meta_patch_url,
+                                                json=meta_patch_payload,
+                                                params=self._client._params(),
+                                                headers=self._client._get_headers())
 
                 updated_details = self._handle_response(200, u'shiny patch', response_patch)
 
@@ -672,19 +624,11 @@ class Shiny(WMLResource):
         # Have to fetch again to reflect updated asset and attachment ids
         url = self._client.service_instance._href_definitions.get_asset_href(shiny_uid)
 
-        if not self._ICP:
-            response = requests.get(
-                url,
-                params=self._client._params(),
-                headers=self._client._get_headers()
-            )
-        else:
-            response = requests.get(
-                url,
-                params=self._client._params(),
-                headers=self._client._get_headers(),
-                verify=False
-            )
+        response = requests.get(
+            url,
+            params=self._client._params(),
+            headers=self._client._get_headers()
+        )
 
         if response.status_code != 200:
             if response.status_code == 404:
@@ -745,12 +689,9 @@ class Shiny(WMLResource):
             raise WMLClientError(
                 u'Cannot delete shiny asset that has existing deployments. Please delete all associated deployments and try again')
 
-        if not self._ICP:
-            response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
-                                    headers=self._client._get_headers())
-        else:
-            response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
-                                      headers=self._client._get_headers(), verify=False)
+        response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
+                                headers=self._client._get_headers())
+
         if response.status_code == 200:
             return self._get_required_element_from_response(response.json())
         else:
@@ -899,12 +840,8 @@ class Shiny(WMLResource):
     def _delete(self, asset_uid):
         Shiny._validate_type(asset_uid, u'asset_uid', STR_TYPE, True)
 
-        if not self._ICP:
-            response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
-                                       headers=self._client._get_headers())
-        else:
-            response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
-                                       headers=self._client._get_headers(), verify=False)
+        response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
+                                   headers=self._client._get_headers())
 
 
     # @docstring_parameter({'str_type': STR_TYPE_NAME})
@@ -944,7 +881,7 @@ class Shiny(WMLResource):
     #                                 headers=self._client._get_headers())
     #     else:
     #         response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid), params=self._client._params(),
-    #                                 headers=self._client._get_headers(), verify=False)
+    #                                 headers=self._client._get_headers())
     #     if response.status_code == 200:
     #         return response.json()["href"]
     #     else:
