@@ -13,7 +13,7 @@
 #  limitations under the License.
 
 from __future__ import print_function
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 from ibm_watson_machine_learning.utils import SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE,SW_SPEC_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos
 from ibm_watson_machine_learning.metanames import SwSpecMetaNames
 from ibm_watson_machine_learning.wml_resource import WMLResource
@@ -105,12 +105,12 @@ class SwSpec(WMLResource):
                     response = requests.get(
                         self._client.service_instance._href_definitions.get_sw_spec_href(sw_spec_uid),
                         params=self._client._params(skip_space_project_chk=True),
-                        headers=self._client._get_headers(), verify=False)
+                        headers=self._client._get_headers())
                 else:
                     response = requests.get(
                         self._client.service_instance._href_definitions.get_sw_spec_href(sw_spec_uid),
                         params=self._client._params(),
-                        headers=self._client._get_headers(), verify=False)
+                        headers=self._client._get_headers())
 
             if response.status_code == 200:
                 return self._get_required_element_from_response(
@@ -127,12 +127,12 @@ class SwSpec(WMLResource):
                     response = requests.get(
                         self._client.service_instance._href_definitions.get_sw_specs_href(),
                         params=self._client._params(skip_space_project_chk=True),
-                        headers=self._client._get_headers(), verify=False)
+                        headers=self._client._get_headers())
                 else:
                     response = requests.get(
                         self._client.service_instance._href_definitions.get_sw_specs_href(),
                         params=self._client._params(),
-                        headers=self._client._get_headers(), verify=False)
+                        headers=self._client._get_headers())
 
             if response.status_code == 200:
                 return {'resources': [self._get_required_element_from_response(x)
@@ -187,7 +187,7 @@ class SwSpec(WMLResource):
         if not self._ICP:
             creation_response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(), data=sw_spec_meta_json)
         else:
-            creation_response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(), data=sw_spec_meta_json, verify=False)
+            creation_response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(), data=sw_spec_meta_json)
 
         sw_spec_details = self._handle_response(201, u'creating sofware specifications', creation_response)
 
@@ -220,7 +220,7 @@ class SwSpec(WMLResource):
             if not self._ICP:
                 response = requests.get(href, params=self._client._params(), headers=self._client._get_headers())
             else:
-                response = requests.get(href, params=self._client._params(), headers=self._client._get_headers(), verify=False)
+                response = requests.get(href, params=self._client._params(), headers=self._client._get_headers())
             self._handle_response(200, u'list sw_specs', response)
             asset_details = self._handle_response(200, u'list assets', response)["resources"]
             sw_spec_values = [
@@ -361,7 +361,7 @@ class SwSpec(WMLResource):
 
                 response = requests.get(self._client.service_instance._href_definitions.get_sw_specs_href(),
                                         params=parameters,
-                                        headers=self._client._get_headers(), verify=False)
+                                        headers=self._client._get_headers())
 
             total_values = self._handle_response(200, u'list assets', response)["total_results"]
             if total_values != 0:
@@ -435,7 +435,7 @@ class SwSpec(WMLResource):
                                     headers=self._client._get_headers())
         else:
             response = requests.delete(self._client.service_instance._href_definitions.get_sw_spec_href(sw_spec_uid), params=self._client._params(),
-                                      headers=self._client._get_headers(), verify=False)
+                                      headers=self._client._get_headers())
         if response.status_code == 200:
             return self._get_required_element_from_response(response.json())
         else:
@@ -480,7 +480,7 @@ class SwSpec(WMLResource):
         if not self._ICP:
             response = requests.put(url, params=self._client._params(), headers=self._client._get_headers())
         else:
-            response = requests.put(url,  params=self._client._params(), headers=self._client._get_headers(), verify=False)
+            response = requests.put(url,  params=self._client._params(), headers=self._client._get_headers())
 
         if response.status_code == 204:
             print("SUCCESS")
@@ -521,15 +521,9 @@ class SwSpec(WMLResource):
 
         url = url + "/package_extensions/" + pkg_extn_id
 
-        if not self._ICP:
-            response = requests.delete(url,
-                                       params=self._client._params(),
-                                       headers=self._client._get_headers())
-        else:
-            response = requests.delete(url,
-                                       params=self._client._params(),
-                                       headers=self._client._get_headers(),
-                                       verify=False)
+        response = requests.delete(url,
+                                   params=self._client._params(),
+                                   headers=self._client._get_headers())
 
         return self._handle_response(204, u'pkg spec delete', response, False)
 
