@@ -1,16 +1,16 @@
-# (C) Copyright IBM Corp. 2020.
+#  (C) Copyright IBM Corp. 2021.
 #
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+#  Licensed under the Apache License, Version 2.0 (the "License");
+#  you may not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
 #
-#      http://www.apache.org/licenses/LICENSE-2.0
+#       http://www.apache.org/licenses/LICENSE-2.0
 #
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS,
+#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#  See the License for the specific language governing permissions and
+#  limitations under the License.
 
 from enum import Enum
 
@@ -32,7 +32,8 @@ __all__ = [
     "MetricsToDirections",
     'PositiveLabelClass',
     'VisualizationTypes',
-    'SamplingTypes'
+    'SamplingTypes',
+    'ImputationStrategy'
 ]
 
 
@@ -161,7 +162,7 @@ class Metrics:
 
     """
     ACCURACY_SCORE = "accuracy"
-    # ACCURACY_AND_DISPARATE_IMPACT_SCORE = "accuracy_and_disparate_impact" TODO: uncomment to add fairness support
+    ACCURACY_AND_DISPARATE_IMPACT_SCORE = "accuracy_and_disparate_impact"
     AVERAGE_PRECISION_SCORE = "average_precision"
     F1_SCORE = "f1"
     LOG_LOSS = "neg_log_loss"
@@ -187,7 +188,7 @@ class Metrics:
     ROOT_MEAN_SQUARED_ERROR = "neg_root_mean_squared_error"
     ROOT_MEAN_SQUARED_LOG_ERROR = "neg_root_mean_squared_log_error"
     R2_SCORE = "r2"
-    # R2_AND_DISPARATE_IMPACT_SCORE = "r2_and_disparate_impact" TODO: uncomment to add fairness support
+    R2_AND_DISPARATE_IMPACT_SCORE = "r2_and_disparate_impact"
 
 
 class Transformers:
@@ -312,3 +313,18 @@ class SamplingTypes:
     """Types of training data sampling"""
     FIRST_N_RECORDS = 'first_n_records'
     RANDOM_STRATIFIED = 'random_stratified'
+
+
+class ImputationStrategy(Enum):
+    """Missing values imputation strategies."""
+    MEAN = 'mean'
+    MEDIAN = 'median'
+    MOST_FREQUENT = 'most_frequent'
+    BEST_OF_DEFAULT_IMPUTERS = 'best_of_default_imputers'
+    VALUE = 'value'
+    FLATTEN_ITERATIVE = 'flatten_iterative'
+    LINEAR = 'linear'
+    CUBIC = 'cubic'
+    PREVIOUS = 'previous'
+    NEXT = 'next'
+    NO_IMPUTATION = 'no_imputation'
\ No newline at end of file
