@@ -12,7 +12,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 import logging
 from ibm_watson_machine_learning.wml_client_error import MissingValue, WMLClientError, NoWMLCredentialsProvided, ApiRequestFailure, UnexpectedType, MissingMetaProp
 from ibm_watson_machine_learning.href_definitions import HrefDefinitions
@@ -152,14 +152,12 @@ class WMLResource:
             raise UnexpectedType(u'details', expected_type, actual_type)
 
     def _check_if_lib_or_def(self, lib_uid):
-
-        verify = False
         lib_details = requests.get(self._client.service_instance._href_definitions.get_custom_library_href(lib_uid),
-                                   headers=self._client._get_headers(), verify=verify)
+                                   headers=self._client._get_headers())
         if lib_details.status_code == 200:
             return lib_details.json()["metadata"]["href"]
         def_details = requests.get(self._client.service_instance._href_definitions.get_model_definition_assets_href() + u'/' + lib_uid,
-                                   params=self._client._params(), headers=self._client._get_headers(), verify=verify)
+                                   params=self._client._params(), headers=self._client._get_headers())
         if def_details.status_code == 200:
             return def_details.json()["href"]
         else:
@@ -193,19 +191,11 @@ class WMLResource:
 
             url = base_url + u'/' + uid
 
-            if not self._ICP and not self._client.WSD:
-                response_get = requests.get(
-                    url,
-                    params,
-                    headers=self._client._get_headers()
-                )
-            else:
-                response_get = requests.get(
-                    url,
-                    params,
-                    headers=self._client._get_headers(),
-                    verify=False
-                )
+            response_get = requests.get(
+                url,
+                params,
+                headers=self._client._get_headers()
+            )
 
             return self._handle_response(200, op_name, response_get)
 
@@ -254,19 +244,11 @@ class WMLResource:
                 }
 
             else:
-                if not self._ICP:
-                    response_get = requests.get(
-                        url,
-                        headers=self._client._get_headers(),
-                        params=params
-                    )
-                else:
-                    response_get = requests.get(
-                        url,
-                        headers=self._client._get_headers(),
-                        params=params,
-                        verify=False
-                    )
+                response_get = requests.get(
+                    url,
+                    headers=self._client._get_headers(),
+                    params=params
+                )
 
                 result = self._handle_response(200, op_name, response_get)
                 if 'resources' in result:
@@ -293,17 +275,10 @@ class WMLResource:
 
             url = base_url + u'/' + uid
 
-            if not self._ICP:
-                response_get = requests.get(
-                    url,
-                    headers=self._client._get_headers()
-                )
-            else:
-                response_get = requests.get(
-                    url,
-                    headers=self._client._get_headers(),
-                    verify=False
-                )
+            response_get = requests.get(
+                url,
+                headers=self._client._get_headers()
+            )
 
             return self._handle_response(200, op_name, response_get)
 
@@ -320,19 +295,11 @@ class WMLResource:
                 raise WMLClientError('Limit cannot be larger than 1000.')
             params.update({u'limit': limit})
         if len (params) > 0:
-            if not self._ICP:
-                response_get = requests.get(
-                    url,
-                    headers=self._client._get_headers(),
-                    params=params
-                )
-            else:
-                response_get = requests.get(
-                    url,
-                    headers=self._client._get_headers(),
-                    params=params,
-                    verify=False
-                )
+            response_get = requests.get(
+                url,
+                headers=self._client._get_headers(),
+                params=params
+            )
 
             return self._handle_response(200, op_name, response_get)
         else:
@@ -340,18 +307,10 @@ class WMLResource:
             resources = []
 
             while True:
-                if not self._ICP:
-                    response_get = requests.get(
-                        url,
-                        headers=self._client._get_headers(),
-
-                    )
-                else:
-                    response_get = requests.get(
-                        url,
-                        headers=self._client._get_headers(),
-                        verify=False
-                    )
+                response_get = requests.get(
+                    url,
+                    headers=self._client._get_headers()
+                )
 
                 result = self._handle_response(200, op_name, response_get)
                 resources.extend(result['resources'])
@@ -374,7 +333,7 @@ class WMLResource:
             return 0
         deployment_href = self._client.service_instance._href_definitions.get_deployments_href() + "?asset_id=" + asset_id
         response_deployment = requests.get(deployment_href, params=self._client._params(),
-                                           headers=self._client._get_headers(), verify=False)
+                                           headers=self._client._get_headers())
         deployment_json = self._handle_response(200, "Get deployment details", response_deployment)
         resources = deployment_json["resources"]
         if resources:
@@ -429,7 +388,7 @@ class WMLResource:
             }
 
         response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(),
-                                     json=data, verify=False)
+                                     json=data)
         self._handle_response(200, u'list ', response)
         asset_details = self._handle_response(200, u'model list', response)["results"]
         model_def_values = [
@@ -507,8 +466,7 @@ class WMLResource:
                 atype_url,
                 params=params,
                 data=atype_payload,
-                headers=aheaders,
-                verify=False
+                headers=aheaders
             )
 
             if asset_type_response.status_code != 200 and \
@@ -519,8 +477,7 @@ class WMLResource:
                 url,
                 params=params,
                 json=cams_payload,
-                headers=headers,
-                verify=False
+                headers=headers
             )
             asset_res_text = 'creating new ' + asset_type[4:]
             asset_details = self._handle_response(201, asset_res_text, create_response)
@@ -550,15 +507,13 @@ class WMLResource:
                     response = requests.put(
                         content_upload_url,
                         files={'file': ('native', fdata, 'application/xml', {'Expires': '0'})},
-                        params=params,
-                        verify=False
+                        params=params
                     )
                 else:
                     response = requests.put(
                         content_upload_url,
                         files={'file': ('native', fdata, 'application/gzip', {'Expires': '0'})},
-                        params=params,
-                        verify=False
+                        params=params
                     )
 
                 if response.status_code == 201:
@@ -583,8 +538,7 @@ class WMLResource:
                     attach_response = requests.post(attach_url,
                                                     data=attach_payload,
                                                     params=params,
-                                                    headers=headers,
-                                                    verify=False)
+                                                    headers=headers)
                     if attach_response.status_code == 201:
                         # remove the tmp file create for content upload
                         if asset_type != 'data_asset':
@@ -610,7 +564,7 @@ class WMLResource:
         delete_endpoint = self._client.service_instance._href_definitions.get_model_definition_assets_href() + "/" + asset_uid
         self._logger.debug(u'Deletion artifact {} endpoint: {}'.format(asset_type, delete_endpoint))
         response_delete = requests.delete(delete_endpoint, params=self._client._params(),
-                                              headers=self._client._get_headers(), verify=False)
+                                              headers=self._client._get_headers())
         return response_delete
 
     def _wsd_get_asset_details(self, asset_type, asset_id, limit=None):
@@ -674,10 +628,10 @@ class WMLResource:
             if self._client.ICP_PLATFORM_SPACES:
                 response = requests.post(url, headers=self._client._get_headers(),
                                          params=self._client._params(skip_for_create=True),
-                                         json=input_json, verify=False)
+                                         json=input_json)
             else:
                 response = requests.post(url, headers=self._client._get_headers(),
-                                         json=input_json, verify=False)
+                                         json=input_json)
 
         return self._handle_response(201, op_name, response)
 
@@ -694,17 +648,10 @@ class WMLResource:
         # CAMS revision creation api takes space_id as a query parameter. Hence
         # params has to be passed
 
-        if not self._ICP and not self._client.WSD:
-            response = requests.post(url,
-                                     headers=self._client._get_headers(),
-                                     params=self._client._params(),
-                                     json=payload_json)
-        else:
-            response = requests.post(url,
-                                     headers=self._client._get_headers(),
-                                     params=self._client._params(),
-                                     json=payload_json,
-                                     verify=False)
+        response = requests.post(url,
+                                 headers=self._client._get_headers(),
+                                 params=self._client._params(),
+                                 json=payload_json)
 
         if response.status_code == 201:
             print("DONE")
@@ -722,19 +669,11 @@ class WMLResource:
             attachments_id_url = self._client.service_instance._href_definitions.get_asset_href(
                 asset_id) + '/attachments/' + current_attachment_id
 
-            if not self._ICP:
-                delete_attachment_response = requests.delete(
-                    attachments_id_url,
-                    headers=self._client._get_headers(),
-                    params=self._client._params()
-                )
-            else:
-                delete_attachment_response = requests.delete(
-                    attachments_id_url,
-                    headers=self._client._get_headers(),
-                    params=self._client._params(),
-                    verify=False
-                )
+            delete_attachment_response = requests.delete(
+                attachments_id_url,
+                headers=self._client._get_headers(),
+                params=self._client._params()
+            )
 
         if delete_attachment_response.status_code == 204 or current_attachment_id is None:
             attachment_meta = {
@@ -746,21 +685,12 @@ class WMLResource:
 
             # STEP 3b.
             # Get the signed url from CAMS to upload the attachment
-            if not self._ICP:
-                attachment_response = requests.post(
-                    attachments_url,
-                    headers=self._client._get_headers(),
-                    params=self._client._params(),
-                    json=attachment_meta
-                )
-            else:
-                attachment_response = requests.post(
-                    attachments_url,
-                    headers=self._client._get_headers(),
-                    json=attachment_meta,
-                    params=self._client._params(),
-                    verify=False
-                )
+            attachment_response = requests.post(
+                attachments_url,
+                headers=self._client._get_headers(),
+                params=self._client._params(),
+                json=attachment_meta
+            )
 
             attachment_details = self._handle_response(201, u'creating new attachment', attachment_response)
             if attachment_response.status_code == 201:
@@ -780,27 +710,17 @@ class WMLResource:
                 else:
                     put_response = requests.put(
                         self._wml_credentials['url'] + attachment_url,
-                        files=file,
-                        verify=False
+                        files=file
                     )
 
                 if put_response.status_code == 201 or put_response.status_code == 200:
                     # STEP 3d.
                     # Mark attachment complete
-                    if not self._ICP:
-                        complete_response = requests.post(
-                            self._client.service_instance._href_definitions.get_attachment_href(asset_id, attachment_id) + "/complete",
-                            headers=self._client._get_headers(),
-                            params=self._client._params()
-
-                        )
-                    else:
-                        complete_response = requests.post(
-                            self._client.service_instance._href_definitions.get_attachment_href(asset_id, attachment_id) + "/complete",
-                            headers=self._client._get_headers(),
-                            params=self._client._params(),
-                            verify=False
-                        )
+                    complete_response = requests.post(
+                        self._client.service_instance._href_definitions.get_attachment_href(asset_id, attachment_id) + "/complete",
+                        headers=self._client._get_headers(),
+                        params=self._client._params()
+                    )
 
                     if complete_response.status_code == 200:
                         print("SUCCESS")
