@@ -54,7 +54,7 @@ class WorkSpace:
     >>>         space_id="...")
     """
 
-    def __init__(self, wml_credentials: dict, project_id: str = None, space_id: str = None) -> None:
+    def __init__(self, wml_credentials: dict, project_id: str = None, space_id: str = None, verify=None) -> None:
         self.wml_credentials = wml_credentials.copy()
         self.project_id = project_id
         self.space_id = space_id
@@ -71,7 +71,7 @@ class WorkSpace:
                 self.wml_credentials['version'] = '3.0.0'
         # --- end note
 
-        self.wml_client = APIClient(wml_credentials=self.wml_credentials)
+        self.wml_client = APIClient(wml_credentials=self.wml_credentials, verify=verify)
 
         if not wml_credentials.get('instance_id'):
             if self.space_id is not None:
