@@ -17,13 +17,12 @@ import logging
 
 logger = logging.getLogger(__name__)
 
+
 class Party:
 
     def __init__(self, **kwargs):
-        logger.warning("The module ibmfl will be deprecated and become part of the Python client. Please use the latest Python client to access the party package.")
         from ibm_watson_machine_learning.party_wrapper import Party
         self.party = Party(**kwargs)
-        self.connection = self.party.connection
 
     def start(self):
         self.party.start()
